This function returns N example risk of bias assessments for the tool specified, where N is set by the user. Assessments are "realistic" in that the judgment in the overall column is set to the highest judgement across the domains for a given study, reflecting the recommendations of the tool creators.
rob_dummy(n, tool = "ROB2", study = TRUE)Other helper:
rob_append_weights(),
rob_save(),
rob_tools()